@@ -11,7 +11,6 @@ from __future__ import unicode_literals
 
 import os
 import re
-import sys
 import json
 import random
 import fnmatch
@@ -196,7 +195,8 @@ class TestApp(object):
         self.authorization_value = value
         if value is not None:
             invalid_value = (
-                "You should use a value like ('Basic', ('user', 'password')) OR ('Bearer', 'token')"
+                "You should use a value like ('Basic', ('user', 'password'))"
+                " OR ('Bearer', 'token') OR ('JWT', 'token')"
             )
             if isinstance(value, (list, tuple)) and len(value) == 2:
                 authtype, val = value
@@ -205,7 +205,7 @@ class TestApp(object):
                     val = ':'.join(list(val))
                     val = b64encode(to_bytes(val)).strip()
                     val = val.decode('latin1')
-                elif authtype == 'Bearer' and val and \
+                elif authtype in ('Bearer', 'JWT') and val and \
                         isinstance(val, (str, text_type)):
                     val = val.strip()
                 else:
@@ -610,7 +610,7 @@ class TestApp(object):
         # verify wsgi compatibility
         app = lint.middleware(self.app) if self.lint else self.app
 
-        ## FIXME: should it be an option to not catch exc_info?
+        # FIXME: should it be an option to not catch exc_info?
         res = req.get_response(app, catch_exc_info=True)
 
         # be sure to decode the content
@@ -672,7 +672,7 @@ class TestApp(object):
                 res)
         if status != res.status_int:
             raise AppError(
-                "Bad response: %s (not %s)", res_status, status)
+                "Bad response: %s (not %s)\n%s", res_status, status, res)
 
     def _check_errors(self, res):
         errors = res.errors
